==> archimedes-1.2.0.tar.bz2: archimedes-1.2.0/src/InP.h <==
/* InP.h -- This file is part of Archimedes release 1.2.0
   Archimedes is a simulator for Submicron and Nanoscaled
   2D III-V Semiconductor Devices.

   Copyright (C) 2004-2011 Jean Michel Sellier
   <jeanmichel.sellier@gmail.com>
   <jsellier@purdue.edu>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


// ######################################################
// Created on 22 aug.2011, Carry le Rouet, France J.M.Sellier
// Last modif. : 26 Aug.2011, Carry le Rouet, J.M.Sellier
// ######################################################

// conduction band calculated using the model : sp3s* (see Vogl)
// data interpolated by a 10-th order polynomial

CB_FULL[INP][0]=2.7377e+06;
CB_FULL[INP][1]=-2.0050e+11;
CB_FULL[INP][2]=9.1995e+09;
CB_FULL[INP][3]=4.2034e+11;
CB_FULL[INP][4]=1.1211e+13;
CB_FULL[INP][5]=-4.6781e+11;
CB_FULL[INP][6]=7.2368e+09;
CB_FULL[INP][7]=-5.0265e+07;
CB_FULL[INP][8]=1.4179e+05;
CB_FULL[INP][9]=2.9053e+01;
CB_FULL[INP][10]=1.4017e+00;

==> archimedes-2.0.1.tar.bz2: archimedes-2.0.1/src/InP.h <==
/* InP.h -- This file is part of Archimedes release 1.2.0
   Archimedes is a simulator for Submicron and Nanoscaled
   2D III-V Semiconductor Devices.

   Copyright (C) 2004-2011 Jean Michel Sellier
   <jeanmichel.sellier@gmail.com>
   <jsellier@purdue.edu>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


// ######################################################
// Created on 22 aug.2011, Carry le Rouet, France J.M.Sellier
// Last modif. : 31 Aug.2011, Carry le Rouet, J.M.Sellier
// ######################################################

// Parabolic conduction band
// Gamma valley

CB_FULL[INP][0]=+6.6630e+23;
CB_FULL[INP][1]=-2.7272e+22;
CB_FULL[INP][2]=+4.7390e+20;
CB_FULL[INP][3]=-4.5570e+18;
CB_FULL[INP][4]=+2.6491e+16;
CB_FULL[INP][5]=-9.5511e+13;
CB_FULL[INP][6]=+2.1070e+11;
CB_FULL[INP][7]=-2.6995e+08;
CB_FULL[INP][8]=+1.9100e+07;
CB_FULL[INP][9]=-4.9156e+01;
CB_FULL[INP][10]=0.0; // 3.1207e-03
